@@ -5,7 +5,7 @@
 ;; Author: Matthew Carter <m@ahungry.com>
 ;; Maintainer: Matthew Carter <m@ahungry.com>
 ;; URL: https://github.com/ahungry/color-theme-ahungry
-;; Version: 1.4.0
+;; Version: 1.5.0
 ;; Keywords: ahungry palette color theme emacs color-theme deftheme
 ;; Package-Requires: ((emacs "24"))
 
@@ -36,6 +36,10 @@
 
 ;;; News:
 
+;;;; Changes since 1.4.0:
+;; - Add Man faces
+;; - Add button face
+
 ;;;; Changes since 1.3.0:
 ;; - Add realgud overlay arrow colors
 ;; - Reverse org-link faces for readability
@@ -279,6 +283,9 @@ Default value:
    '(realgud-overlay-arrow1 ((t (:foreground "#6699ff"))))
    '(realgud-overlay-arrow2 ((t (:foreground "#0099ff"))))
    '(realgud-overlay-arrow3 ((t (:foreground "#00aa99"))))
+   '(button ((t (:foreground "#0055ff" :bold t :underline t))))
+   '(Man-overstrike ((t (:foreground "yellow" :bold t))))
+   '(Man-underline ((t (:foreground "orange" :underline t))))
    )
   (custom-theme-set-variables
    'ahungry
